==> aws-cdk.aws-networkmanager-1.144.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistrationProps(p) {
}
function _aws_cdk_aws_networkmanager_CfnLinkAssociationProps(p) {
}
function _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociationProps(p) {
}
function _aws_cdk_aws_networkmanager_CfnGlobalNetworkProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnLinkProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bandwidth))
        _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty(p.bandwidth);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnDeviceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnSiteProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociation(p) {
}
function _aws_cdk_aws_networkmanager_CfnLinkAssociation(p) {
}
function _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistration(p) {
}
function _aws_cdk_aws_networkmanager_CfnGlobalNetwork(p) {
}
function _aws_cdk_aws_networkmanager_CfnLink(p) {
}
function _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty(p) {
}
function _aws_cdk_aws_networkmanager_CfnDevice(p) {
}
function _aws_cdk_aws_networkmanager_CfnDevice_LocationProperty(p) {
}
function _aws_cdk_aws_networkmanager_CfnSite(p) {
}
function _aws_cdk_aws_networkmanager_CfnSite_LocationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistrationProps, _aws_cdk_aws_networkmanager_CfnLinkAssociationProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociationProps, _aws_cdk_aws_networkmanager_CfnGlobalNetworkProps, _aws_cdk_aws_networkmanager_CfnLinkProps, _aws_cdk_aws_networkmanager_CfnDeviceProps, _aws_cdk_aws_networkmanager_CfnSiteProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociation, _aws_cdk_aws_networkmanager_CfnLinkAssociation, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistration, _aws_cdk_aws_networkmanager_CfnGlobalNetwork, _aws_cdk_aws_networkmanager_CfnLink, _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty, _aws_cdk_aws_networkmanager_CfnDevice, _aws_cdk_aws_networkmanager_CfnDevice_LocationProperty, _aws_cdk_aws_networkmanager_CfnSite, _aws_cdk_aws_networkmanager_CfnSite_LocationProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-networkmanager-1.145.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistrationProps(p) {
}
function _aws_cdk_aws_networkmanager_CfnLinkAssociationProps(p) {
}
function _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociationProps(p) {
}
function _aws_cdk_aws_networkmanager_CfnGlobalNetworkProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnLinkProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bandwidth))
        _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty(p.bandwidth);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnDeviceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnSiteProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociation(p) {
}
function _aws_cdk_aws_networkmanager_CfnLinkAssociation(p) {
}
function _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistration(p) {
}
function _aws_cdk_aws_networkmanager_CfnGlobalNetwork(p) {
}
function _aws_cdk_aws_networkmanager_CfnDevice(p) {
}
function _aws_cdk_aws_networkmanager_CfnDevice_LocationProperty(p) {
}
function _aws_cdk_aws_networkmanager_CfnSite(p) {
}
function _aws_cdk_aws_networkmanager_CfnSite_LocationProperty(p) {
}
function _aws_cdk_aws_networkmanager_CfnLink(p) {
}
function _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistrationProps, _aws_cdk_aws_networkmanager_CfnLinkAssociationProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociationProps, _aws_cdk_aws_networkmanager_CfnGlobalNetworkProps, _aws_cdk_aws_networkmanager_CfnLinkProps, _aws_cdk_aws_networkmanager_CfnDeviceProps, _aws_cdk_aws_networkmanager_CfnSiteProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociation, _aws_cdk_aws_networkmanager_CfnLinkAssociation, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistration, _aws_cdk_aws_networkmanager_CfnGlobalNetwork, _aws_cdk_aws_networkmanager_CfnDevice, _aws_cdk_aws_networkmanager_CfnDevice_LocationProperty, _aws_cdk_aws_networkmanager_CfnSite, _aws_cdk_aws_networkmanager_CfnSite_LocationProperty, _aws_cdk_aws_networkmanager_CfnLink, _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty };
module.exports.DeprecationError = DeprecationError;
